@@ -3,9 +3,10 @@ package Padre::Plugin::Moose::Attribute;
 use Moose;
 use namespace::clean;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
-with 'Padre::Plugin::Moose::CodeGen';
+with 'Padre::Plugin::Moose::CanGenerateCode';
+with 'Padre::Plugin::Moose::CanProvideHelp';
 
 has 'name'     => ( is => 'rw', isa => 'Str' );
 has 'type'     => ( is => 'rw', isa => 'Str', default => 'Str' );
@@ -13,7 +14,7 @@ has 'access'   => ( is => 'rw', isa => 'Str', default => 'rw' );
 has 'trigger'  => ( is => 'rw', isa => 'Str' );
 has 'required' => ( is => 'rw', isa => 'Bool' );
 
-sub to_code {
+sub generate_code {
 	my $self    = shift;
 	my $comment = shift;
 
@@ -29,6 +30,11 @@ sub to_code {
 	return $code;
 }
 
+sub provide_help {
+	require Wx;
+	return Wx::gettext('An attribute is a property that every member of a class has.');
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
