@@ -3,15 +3,16 @@ package Padre::Plugin::Moose::Subtype;
 use namespace::clean;
 use Moose;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
-with 'Padre::Plugin::Moose::CodeGen';
+with 'Padre::Plugin::Moose::CanGenerateCode';
+with 'Padre::Plugin::Moose::CanProvideHelp';
 
 has 'name'          => ( is => 'rw', isa => 'Str' );
 has 'constraint'    => ( is => 'rw', isa => 'Str', default => '' );
 has 'error_message' => ( is => 'rw', isa => 'Str', default => '' );
 
-sub to_code {
+sub generate_code {
 	my $self = shift;
 
 	my $code
@@ -27,6 +28,11 @@ sub to_code {
 	return $code;
 }
 
+sub provide_help {
+	require Wx;
+	return Wx::gettext('A subtype provides the ability to create custom type constraints to be used in attribute definition.');
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
